summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorHans Ulrich Niedermann <hun@n-dimensional.de>2008-06-22 17:07:40 +0200
committerHans Ulrich Niedermann <hun@n-dimensional.de>2008-07-15 12:28:51 +0200
commitfe118b849167155dd9bcfbc525dfce391f1a11bb (patch)
tree747305ed5c70063d6f5c4c80a31adb44cfcbccdf
parent7db16ebc9e7bf05b73169d233c015a2a16379f45 (diff)
More docs/design phase
-rw-r--r--nbb/nbblib/main.py33
1 files changed, 23 insertions, 10 deletions
diff --git a/nbb/nbblib/main.py b/nbb/nbblib/main.py
index 42e01e5..8bdd561 100644
--- a/nbb/nbblib/main.py
+++ b/nbb/nbblib/main.py
@@ -23,20 +23,27 @@ DONE:
* Build system support: automake/autoconf
TODO:
- * Build system support: cmake, ...
+ * Build system support: cmake, scons, ...
* Fine-tune init, configure, build, install commands with knowledge
- gained with git-amb.
+ gained with git-amb, especially the command interdependencies.
* implement *-sh and *-run commands
+ * General removal of redundancy in Python code.
+ * More declarative syntax elements in the Python code.
+ * Use declarations for command line parsing, and help text generation.
+ * Add global --nick or similar option to determine the branch
+ name to use for composing the pathes.
+ * Store config in ${srcdir}/.nbb.conf instead of 'git config'?
+ More portable. bzr does not have a config interface, for example.
* Design nice user interface. Requirements:
* print top_srcdir, builddir, installdir
* start subshell in top_srcdir, builddir, installdir
- * run 'autoreconf' type step
- * run 'configure' type step
- * run 'make' type step
- * run 'make install' type step
- * run custom (make) commands
+ * run 'autoreconf' type step. OK: 'init'
+ * run 'configure' type step. OK: 'configure'
+ * run 'make' type step. OK: 'build'
+ * run 'make install' type step. OK: 'install'
+ * run custom (make) commands. OK: 'make'
* Bash syntax completion for that user interface.
- * Man page or something similar.
+ * Man page or something similar. Generate from help texts?
Command line interface (TBD):
@@ -47,7 +54,13 @@ Command line interface (TBD):
$ %(prog)s [general options] install [command specific options]
Run cleanup commands:
- TBD
+ $ %(prog)s [general options] purge [command specific options]
+ Command specific options:
+ --builddir-only
+ --installdir-only
+ $ %(prog)s [general options] purge-all # either this
+ $ %(prog)s [general options] purge --all # or that
+ TBD: 'make clean', 'make distclean' and similar stuff?
Get/set config:
$ %(prog)s [general options] config srcdir
@@ -23,20 +23,27 @@ DONE:
* Design nice user interface. Requirements:
- * print top_srcdir, builddir, installdir
+ * print top_srcdir, builddir, installdir. OK: 'config'
* start subshell in top_srcdir, builddir, installdir